==> ark-15.08.0.tar.xz: ark-15.08.0/plugins/clizipplugin/kerfuffle_clizip.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_clizip
X-KDE-PluginInfo-Author=Harald Hvaal
X-KDE-PluginInfo-Email=haraldhv@stud.ntnu.no
X-KDE-PluginInfo-Name=kerfuffle_clizip
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=GPLv2+
X-KDE-Priority=160
X-KDE-Kerfuffle-APIRevision=1
X-KDE-Kerfuffle-ReadWrite=true
X-KDE-Kerfuffle-EncryptEntries=true
X-KDE-Kerfuffle-EncryptHeader=false
Name=ZIP archive plugin
Name[ar]=ملحق أرشيف ZIP
Name[ast]=Complementu d'archivos ZIP
Name[bg]=Приставка за архиви ZIP
Name[bs]=Priključak ZIP arhiva
Name[ca]=Connector per arxius ZIP
Name[ca@valencia]=Connector per arxius ZIP
Name[cs]=Modul pro archiv ZIP
Name[da]=Plugin til ZIP-arkiver
Name[de]=ZIP-Archiv-Modul
Name[el]=Πρόσθετο αρχειοθήκης ZIP
Name[en_GB]=ZIP archive plugin
Name[es]=Complemento de archivo comprimido ZIP
Name[et]=ZIP-arhiivi plugin
Name[eu]=ZIP artxiboen plugina
Name[fi]=Zip-pakkaustuki
Name[fr]=Module externe d'archive « ZIP »
Name[ga]=Breiseán cartlainne ZIP
Name[gl]=Extensión de arquivo ZIP
Name[hr]=Arhivni priključak ZIP
Name[hu]=ZIP modul
Name[ia]=Plugin de archivar zip
Name[id]=Pengaya arsip ZIP
Name[it]=estensione per archivi ZIP
Name[ja]=ZIP アーカイブ用プラグイン
Name[kk]=ZIP архив плагині
Name[km]=កម្មវិធី​ជំនួយ​ប័ណ្ណសារ ZIP
Name[ko]=ZIP 압축 플러그인
Name[lt]=ZIP archyvo priedas
Name[lv]=ZIP arhīvu spraudnis
Name[mr]=ZIP संग्रह प्लगइन
Name[nb]=Programtillegg for ZIP-arkiv
Name[nds]=Zip-Archievmoduul
Name[nl]=ZIP-archiefplug-in
Name[nn]=ZIP-arkivtillegg
Name[pa]=ਜ਼ਿੱਪ ਅਕਾਇਵ ਪਲੱਗਇਨ
Name[pl]=Wtyczka archiwów ZIP
Name[pt]='Plugin' de pacotes ZIP
Name[pt_BR]=Plugin de arquivos ZIP
Name[ro]=Modul de arhivă ZIP
Name[ru]=Поддержка архивов ZIP
Name[sk]=Modul ZIP archívu
Name[sl]=Vstavek za arhive ZIP
Name[sq]=ZIP arkiv plugin
Name[sr]=Прикључак ЗИП архива
Name[sr@ijekavian]=Прикључак ЗИП архива
Name[sr@ijekavianlatin]=Priključak ZIP arhiva
Name[sr@latin]=Priključak ZIP arhiva
Name[sv]=Insticksprogram för ZIP-arkiv
Name[th]=ส่วนเสริมการจัดการแฟ้มจัดเก็บบีบอัดแบบ ZIP
Name[tr]=ZIP arşivi eklentisi
Name[uk]=Додаток для архівів ZIP
Name[x-test]=xxZIP archive pluginxx
Name[zh_CN]=ZIP 归档插件
Name[zh_TW]=ZIP 壓縮檔外掛程式
MimeType=@SUPPORTED_CLIZIP_MIMETYPES@

==> ark-15.11.80.tar.xz: ark-15.11.80/plugins/clizipplugin/kerfuffle_clizip.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_clizip
X-KDE-PluginInfo-Author=Harald Hvaal
X-KDE-PluginInfo-Email=haraldhv@stud.ntnu.no
X-KDE-PluginInfo-Name=kerfuffle_clizip
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=GPLv2+
X-KDE-Priority=160
X-KDE-Kerfuffle-APIRevision=1
X-KDE-Kerfuffle-ReadWrite=true
X-KDE-Kerfuffle-EncryptEntries=@ENCRYPT_ENTRIES_MIMETYPES@
Name=ZIP archive plugin
Name[ar]=ملحق أرشيف ZIP
Name[ast]=Complementu d'archivos ZIP
Name[bg]=Приставка за архиви ZIP
Name[bs]=Priključak ZIP arhiva
Name[ca]=Connector per arxius ZIP
Name[ca@valencia]=Connector per arxius ZIP
Name[cs]=Modul pro archiv ZIP
Name[da]=Plugin til ZIP-arkiver
Name[de]=ZIP-Archiv-Modul
Name[el]=Πρόσθετο αρχειοθήκης ZIP
Name[en_GB]=ZIP archive plugin
Name[es]=Complemento de archivo comprimido ZIP
Name[et]=ZIP-arhiivi plugin
Name[eu]=ZIP artxiboen plugina
Name[fi]=Zip-pakkaustuki
Name[fr]=Module externe d'archive « ZIP »
Name[ga]=Breiseán cartlainne ZIP
Name[gl]=Extensión de arquivo ZIP
Name[hr]=Arhivni priključak ZIP
Name[hu]=ZIP modul
Name[ia]=Plugin de archivar zip
Name[id]=Pengaya arsip ZIP
Name[it]=estensione per archivi ZIP
Name[ja]=ZIP アーカイブ用プラグイン
Name[kk]=ZIP архив плагині
Name[km]=កម្មវិធី​ជំនួយ​ប័ណ្ណសារ ZIP
Name[ko]=ZIP 압축 플러그인
Name[lt]=ZIP archyvo priedas
Name[lv]=ZIP arhīvu spraudnis
Name[mr]=ZIP संग्रह प्लगइन
Name[nb]=Programtillegg for ZIP-arkiv
Name[nds]=Zip-Archievmoduul
Name[nl]=ZIP-archiefplug-in
Name[nn]=ZIP-arkivtillegg
Name[pa]=ਜ਼ਿੱਪ ਅਕਾਇਵ ਪਲੱਗਇਨ
Name[pl]=Wtyczka archiwów ZIP
Name[pt]='Plugin' de pacotes ZIP
Name[pt_BR]=Plugin de arquivos ZIP
Name[ro]=Modul de arhivă ZIP
Name[ru]=Поддержка архивов ZIP
Name[sk]=Modul ZIP archívu
Name[sl]=Vstavek za arhive ZIP
Name[sq]=ZIP arkiv plugin
Name[sr]=Прикључак ЗИП архива
Name[sr@ijekavian]=Прикључак ЗИП архива
Name[sr@ijekavianlatin]=Priključak ZIP arhiva
Name[sr@latin]=Priključak ZIP arhiva
Name[sv]=Insticksprogram för ZIP-arkiv
Name[th]=ส่วนเสริมการจัดการแฟ้มจัดเก็บบีบอัดแบบ ZIP
Name[tr]=ZIP arşivi eklentisi
Name[uk]=Додаток для архівів ZIP
Name[x-test]=xxZIP archive pluginxx
Name[zh_CN]=ZIP 归档插件
Name[zh_TW]=ZIP 壓縮檔外掛程式
MimeType=@SUPPORTED_CLIZIP_MIMETYPES@
